"""Run the interactive tools."""
from .tools import InsteonCmd

InsteonCmd.start()
